Module headers

Module headers 

Constants

PARAMETERS
Header containing parameters for SQL query binding.
QUERY
Header for the SQL query to execute (overrides URI query).
ROW_COUNT
Header containing the number of rows returned by a SELECT query.
UPDATE_COUNT
Header containing the number of rows affected by an INSERT/UPDATE/DELETE.