pub struct SqlGlobalConfig {
pub max_connections: u32,
pub min_connections: u32,
pub idle_timeout_secs: u64,
pub max_lifetime_secs: u64,
pub ssl_mode: Option<String>,
pub ssl_root_cert: Option<String>,
pub ssl_cert: Option<String>,
pub ssl_key: Option<String>,
}Expand description
Global configuration for SQL component.
This struct supports serde deserialization with defaults and builder methods. It holds pool configuration that can be applied as defaults to endpoints.
Fields
max_connections: u32min_connections: u32idle_timeout_secs: u64max_lifetime_secs: u64ssl_mode: Option<String>ssl_root_cert: Option<String>ssl_cert: Option<String>ssl_key: Option<String>Implementations
Sourceimpl SqlGlobalConfig
impl SqlGlobalConfig
pub fn new() -> Self
pub fn with_max_connections(self, value: u32) -> Self
pub fn with_min_connections(self, value: u32) -> Self
pub fn with_idle_timeout_secs(self, value: u64) -> Self
pub fn with_max_lifetime_secs(self, value: u64) -> Self
pub fn with_ssl_mode(self, value: impl Into<String>) -> Self
pub fn with_ssl_root_cert(self, value: impl Into<String>) -> Self
pub fn with_ssl_cert(self, value: impl Into<String>) -> Self
pub fn with_ssl_key(self, value: impl Into<String>) -> Self